@@ -36,13 +36,15 @@ from functools import partial
 from queue import Queue, Full, Empty
 from concurrent.futures import ThreadPoolExecutor
 import time
+import operator
 
 import logging
 log = logging.getLogger('kenozooid.driver.su')
 
 import kenozooid.uddf as ku
+import kenozooid.data as kd
 import kenozooid.component as kc
-from kenozooid.driver import DeviceDriver, MemoryDump, DeviceError
+from kenozooid.driver import DeviceDriver, DataParser, DeviceError
 from kenozooid.units import C2K
 
 SIZE_MEM_USER = 16384
@@ -184,10 +186,10 @@ class SensusUltraDriver(object):
 
 
 
-@kc.inject(MemoryDump, id='su')
-class SensusUltraMemoryDump(object):
+@kc.inject(DataParser, id='su', data=())
+class SensusUltraDataParser(object):
     """
-    Reefnet Sensus Ultra dive logger memory dump.
+    Reefnet Sensus Ultra dive logger data parser.
     """
 
     def dump(self):
@@ -253,7 +255,7 @@ class SensusUltraMemoryDump(object):
         # boot time = host time - device time (sensus time)
         btime = time.mktime(dump.datetime.timetuple()) - hdp.time
 
-        dq = Queue(5)
+        dq = Queue(10)
         parse_dive = partial(self.parse_dive,
                 parser=parser, boot_time=btime, dives=dq)
         f = FuncDive(parse_dive)
@@ -263,6 +265,17 @@ class SensusUltraMemoryDump(object):
         return _iterate(dq, extract_dives)
 
 
+    def gases(self, data):
+        """
+        Return empty tuple - no gas information stored by Sensus Ultra.
+        
+        :Parameters:
+         data
+            Sensus Ultra data.
+        """
+        return ()
+
+
     def version(self, data):
         """
         Get Sensus Ultra version from raw data.
@@ -299,10 +312,6 @@ class SensusUltraMemoryDump(object):
          dives
             Queue of dives to be consumed by caller.
         """
-        _f = 'depth', 'time', 'temp'
-        _q = 'uddf:depth', 'uddf:divetime', 'uddf:temperature'
-        UDDF_SAMPLE = OrderedDict(zip(_f, _q))
-
         lib = ct.CDLL('libdivecomputer.so.0')
         lib.parser_set_data(parser, buffer, size)
 
@@ -314,55 +323,37 @@ class SensusUltraMemoryDump(object):
         st = datetime.fromtimestamp(boot_time - header.interval + header.time)
         log.debug('got dive time: {0}'.format(st))
 
-        sq = Queue(5)
+        samples = []
         parse_sample = partial(self.parse_sample,
                 dive_header=header,
                 sdata={},
-                sq=sq)
+                sq=samples)
         
         f = FuncSample(parse_sample)
-        extract_samples = partial(lib.parser_samples_foreach,
-            parser, f, None)
-
-        max_depth = 0
-        min_temp = 10000   # in Kelvin
-        samples = []
-        for sdata in _iterate(sq, extract_samples):
-            n = ku.create_dive_profile_sample(None, UDDF_SAMPLE, **sdata)
-            samples.append(n)
+        lib.parser_samples_foreach(parser, f, None)
 
         log.debug('removing {} endcount samples'.format(header.endcount))
         del samples[-header.endcount:]
 
         # dive summary after endcount removal
-        max_depth = max(float(ku.xp_first(n, './uddf:depth/text()'))
-            for n in samples)
-        min_temp = min(float(ku.xp_first(n, './uddf:temperature/text()'))
-            for n in samples)
-        duration = int(ku.xp_first(samples[-1], './uddf:divetime/text()')) \
-            + header.interval
-
-        # finally, create dive node
-        dn = ku.create_dive_data(datetime=st, depth=max_depth,
-            duration=duration, temp=min_temp)
-
-        # each dive starts below DiveHeader.threshold, therefore
-        # inject first sample required by UDDF
-        ku.create_dive_profile_sample(dn, UDDF_SAMPLE,
-                depth=0.0, time=0)
-
-        snode = ku.xp_first(dn, './uddf:samples')
-
-        for n in samples:
-            snode.append(n)
+        max_depth = max(samples, key=operator.attrgetter('depth')).depth
+        min_temp = min(samples, key=operator.attrgetter('temp')).temp
+        duration = samples[-1].time + header.interval
+        
+        # each dive starts below DiveHeader.threshold, therefore inject
+        # first sample required by UDDF
+        samples.insert(0, kd.Sample(depth=0.0, time=0))
 
         # each dive ends at about DiveHeader.threshold depth, therefore
         # inject last sample required by UDDF
-        ku.create_dive_profile_sample(dn, UDDF_SAMPLE,
-                depth=0.0, time=duration)
+        samples.append(kd.Sample(depth=0.0, time=duration))
+
+        # finally, create dive data
+        dive = kd.Dive(datetime=st, depth=max_depth, duration=duration,
+                temp=min_temp, profile=samples)
 
         try:
-            dives.put(dn, timeout=30)
+            dives.put(dive, timeout=30)
         except Full:
             log.error('could not parse dives due to internal queue timeout')
             return 0
@@ -387,18 +378,22 @@ class SensusUltraMemoryDump(object):
          sdata
             Temporary sample data.
          sq
-            Samples 
+            List of samples. 
         """
         # depth is the last sample type generated by libdivecomputer,
         # create the waypoint then
         if st == SampleType.time:
             sdata['time'] = sample.time
         elif st == SampleType.temperature:
-            sdata['temp'] = C2K(sample.temperature)
+            sdata['temp'] = round(C2K(sample.temperature), 1)
         elif st == SampleType.depth:
-            sdata['depth'] = sample.depth
+            # Sensus Ultra might return negative values near 0, so use max
+            sdata['depth'] = round(max(sample.depth, 0), 1)
 
-            sq.put(sdata.copy())
+            s = kd.Sample(**sdata)
+            log.debug('got sample {}'.format(sdata))
+
+            sq.append(s)
             sdata.clear() # clear temporary data
         else:
             log.warn('unknown sample type', st)
