@@ -59,14 +59,16 @@ def list_dives(fin):
             temp = ''
             if dive.temp is not None:
                 temp = '{:.1f}\u00b0C'.format(K2C(dive.temp))
-            yield (format(dive.time, FMT_DIVETIME), depth,
-                    duration, temp)
+            yield (format(dive.datetime, FMT_DIVETIME), depth, duration, temp)
         except TypeError as ex:
             log.debug(ex)
             log.warn('invalid dive data, skipping dive')
 
 
-def add_dive(lfile, time=None, depth=None, duration=None, dive_no=None,
+# split into add_dive and copy_dive
+# extract buddies adding and setting dive site functionality into separate
+# functions
+def add_dive(lfile, datetime=None, depth=None, duration=None, dive_no=None,
         pfile=None, qsite=None, qbuddies=()):
     """
     Add new dive to logbook file.
@@ -79,8 +81,8 @@ def add_dive(lfile, time=None, depth=None, duration=None, dive_no=None,
     :Parameters:
      lfile
         Logbook file.
-     time
-        Dive time.
+     datetime
+        Dive date and time.
      depth
         Dive maximum depth.
      duration
@@ -150,13 +152,14 @@ def add_dive(lfile, time=None, depth=None, duration=None, dive_no=None,
             l.set('ref', b_id)
 
         # set reference to dive site (as first link)
-        l, *_ = ku.create_node('uddf:link', parent=n, append=False)
-        l.set('ref', site_id)
+        if site_id:
+            l, *_ = ku.create_node('uddf:link', parent=n, append=False)
+            l.set('ref', site_id)
 
-    elif (time, depth, duration) is not (None, None, None):
+    elif (datetime, depth, duration) is not (None, None, None):
         log.debug('creating dive data')
         duration = int(duration * 60)
-        ku.create_dive_data(doc, time=time, depth=depth,
+        ku.create_dive_data(doc, datetime=datetime, depth=depth,
                 duration=duration, site=site_id, buddies=buddy_ids)
     else:
         raise ValueError('Dive data or dive profile needs to be provided')
